kss_selector_param
open | /demo/kss_selector_param_multiprop.html |
click | button_1 |
waitForValue | button_2 | RESET ME
assertValue | button_2 | RESET ME
click | button_2 |
waitForValue | button_2 | Watch me
assertValue | button_2 | Watch me
click | button_3 |
waitForValue | button_4 | RESET ME
assertValue | button_4 | RESET ME
click | button_4 |
waitForValue | button_4 | Watch me
assertValue | button_4 | Watch me